package main

import "crypto/x509"
import "encoding/pem"
import "io/ioutil"

func main() {
	var bytes []byte
	var err error
	var bl *pem.Block
	var revocation_list *x509.RevocationList
	var ca *x509.Certificate

	// load CRL
	bytes, err = ioutil.ReadFile("ca.crl")
	if err != nil {
		panic(err)
	}
	bl, _ = pem.Decode(bytes)
	if bl == nil {
		panic("wrong pem format")
	}
	revocation_list, err = x509.ParseRevocationList(bl.Bytes)
	if err != nil {
		panic(err)
	}

	// load CA ok
	bytes, err = ioutil.ReadFile("ca.pem")
	if err != nil {
		panic(err)
	}
	bl, _ = pem.Decode(bytes)
	if bl == nil {
		panic("wrong pem format")
	}
	ca, err = x509.ParseCertificate(bl.Bytes)
	if err != nil {
		panic(err)
	}

	// Test signature
	err = revocation_list.CheckSignatureFrom(ca)
	if err != nil {
		println("Unexpected error: %s\n", err.Error())
	}

	// load CA very wrong
	bytes, err = ioutil.ReadFile("ca_very_wrong.pem")
	if err != nil {
		panic(err)
	}
	bl, _ = pem.Decode(bytes)
	if bl == nil {
		panic("wrong pem format")
	}
	ca, err = x509.ParseCertificate(bl.Bytes)
	if err != nil {
		panic(err)
	}

	// Test signature
	err = revocation_list.CheckSignatureFrom(ca)
	if err == nil {
		println("Expect error, got success\n")
	}

	// load CA wrong
	bytes, err = ioutil.ReadFile("ca_wrong.pem")
	if err != nil {
		panic(err)
	}
	bl, _ = pem.Decode(bytes)
	if bl == nil {
		panic("wrong pem format")
	}
	ca, err = x509.ParseCertificate(bl.Bytes)
	if err != nil {
		panic(err)
	}

	// Test signature
	err = revocation_list.CheckSignatureFrom(ca)
	if err == nil {
		println("Expect error, got success\n")
	}

}
